diff --git a/components/bio-formats/src/loci/formats/in/FV1000Reader.java b/components/bio-formats/src/loci/formats/in/FV1000Reader.java
index 3f3b811..ac61846 100644
--- a/components/bio-formats/src/loci/formats/in/FV1000Reader.java
+++ b/components/bio-formats/src/loci/formats/in/FV1000Reader.java
@@ -143,6 +143,7 @@ public class FV1000Reader extends FormatReader {
     new Hashtable<Integer, String>();
   private Hashtable<Integer, String> roiFilenames =
     new Hashtable<Integer, String>();
+  private Vector<PlaneData> planes;
 
   private POIService poi;
 
@@ -342,6 +343,7 @@ public class FV1000Reader extends FormatReader {
       creationDate = null;
       lut = null;
       channels = null;
+      planes = null;
       if (lutNames != null) {
         lutNames.clear();
       }
@@ -381,6 +383,7 @@ public class FV1000Reader extends FormatReader {
     wavelengths = new Vector<Integer>();
     illuminations = new Vector<String>();
     channels = new Vector<ChannelData>();
+    planes = new Vector<PlaneData>();
 
     String oifName = null;
 
@@ -665,6 +668,7 @@ public class FV1000Reader extends FormatReader {
         tiffs.add(ii, file);
       }
 
+      PlaneData plane = new PlaneData();
       for (int dim=0; dim<NUM_DIMENSIONS; dim++) {
         IniTable axis = pty.getTable("Axis " + dim + " Parameters");
         if (axis == null) break;
@@ -678,14 +682,22 @@ public class FV1000Reader extends FormatReader {
           if (addAxis && getDimensionOrder().indexOf("Z") == -1) {
             ms0.dimensionOrder += "Z";
           }
+          plane.positionZ = Double.parseDouble(axis.get("AbsPositionValue"));
         }
         else if (dim == 4) {
           if (addAxis && getDimensionOrder().indexOf("T") == -1) {
             ms0.dimensionOrder += "T";
           }
+          plane.deltaT = Double.parseDouble(axis.get("AbsPositionValue"));
         }
+        else if (dim == 7) {
+          plane.positionX = Double.parseDouble(axis.get("AbsPositionValueX"));
+          plane.positionY = Double.parseDouble(axis.get("AbsPositionValueY"));
+        }
+
       }
       ms0.bitsPerPixel = validBits;
+      planes.add(plane);
 
       IniTable acquisition = pty.getTable("Acquisition Parameters Common");
       if (acquisition != null) {
@@ -900,7 +912,7 @@ public class FV1000Reader extends FormatReader {
 
     MetadataStore store = makeFilterMetadata();
 
-    MetadataTools.populatePixels(store, this);
+    MetadataTools.populatePixels(store, this, true);
 
     if (creationDate != null) {
       creationDate = creationDate.replaceAll("'", "");
@@ -1101,6 +1113,15 @@ public class FV1000Reader extends FormatReader {
         nextROI = parseROIFile(filename, store, nextROI, i);
       }
     }
+
+    // Populate metadata for the planes
+    for (int i=0; i<planes.size(); i++) {
+      PlaneData plane = planes.get(i);
+      store.setPlaneDeltaT(plane.deltaT, 0, i);
+      store.setPlanePositionX(plane.positionX, 0, i);
+      store.setPlanePositionY(plane.positionY, 0, i);
+      store.setPlanePositionZ(plane.positionZ, 0, i);
+    }
   }
 
   private int parseROIFile(String filename, MetadataStore store, int nextROI,
@@ -1616,6 +1637,7 @@ public class FV1000Reader extends FormatReader {
   private IniList getIniFile(String filename)
     throws FormatException, IOException
   {
+    LOGGER.debug("getIniFile processing: " + filename);
     RandomAccessInputStream stream = getFile(filename);
     String data = stream.readString((int) stream.length());
     if (!data.startsWith("[")) {
@@ -1656,4 +1678,10 @@ public class FV1000Reader extends FormatReader {
     public String barrierFilter;
   }
 
+  class PlaneData {
+    public Double deltaT;
+    public Double positionX;
+    public Double positionY;
+    public Double positionZ;
+  }
 }
diff --git a/components/scifio/src/loci/formats/FormatTools.java b/components/scifio/src/loci/formats/FormatTools.java
index 78b12f2..e5ffd44 100644
--- a/components/scifio/src/loci/formats/FormatTools.java
+++ b/components/scifio/src/loci/formats/FormatTools.java
@@ -798,8 +798,8 @@ public final class FormatTools {
     if (x < 0 || y < 0 || w < 0 || h < 0 || (x + w) >  width ||
       (y + h) > height)
     {
-      throw new FormatException("Invalid tile size: x=" + x + ", y=" + y +
-        ", w=" + w + ", h=" + h);
+       throw new FormatException("Invalid tile size: x=" + x + ", y=" + y +
+        ", w=" + w + ", h=" + h + ", width=" + width + ", height=" + height);
     }
   }
 